﻿using System.ServiceModel;
using System.ServiceModel.Channels;
using System;
using System.Collections.Generic;
using System.Text;
using ProductsClient.ProductsService;

namespace ProductsClient
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("Press ENTER when the service has started");
            Console.ReadLine();

            Client client = new Client();
            client.TestProductsService();

            Console.WriteLine("Press ENTER to finish");
            Console.ReadLine();
        }
    }

    public class Client
    {
        private ProductsServiceClient proxy = null;

        public void TestProductsService()
        {
            // Create a proxy object and connect to the service
            proxy = new ProductsServiceClient("WS2007HttpBinding_IProductsServiceV3");

            // Test the operations in the service
            try
            {
                // Obtain a list of products
                Console.WriteLine("Test 1: List all products");
                string[] productNumbers = proxy.ListProducts();
                foreach (string productNumber in productNumbers)
                {
                    Console.WriteLine("Number: {0}", productNumber);
                }
                Console.WriteLine();

                // Fetch the details for a specific bicycle frame
                Console.WriteLine("Test 2: Display the details of a bicycle frame");
                ProductData product = proxy.GetProduct("FR-M21S-40");
                Console.WriteLine("Number: {0}", product.ProductNumber);
                Console.WriteLine("Name: {0}", product.Name);
                Console.WriteLine("Color: {0}", product.Color);
                Console.WriteLine("Price: {0:C}", product.ListPrice);
                Console.WriteLine();

                // Modify the price of this bicycle frame
                Console.WriteLine("Test 3: Modify the price of a bicycle frame");
                if (proxy.ChangePrice("FR-M21S-40", product.ListPrice + 10))
                {
                    product = proxy.GetProduct("FR-M21S-40");
                    Console.WriteLine("Price changed. New price: {0:C}",
                                      product.ListPrice);
                }
                else
                {
                    Console.WriteLine("Price change failed");
                }
                Console.WriteLine();
            }

            catch (Exception e)
            {
                Console.WriteLine("Exception: {0}", e.Message);
            }
            
            // Disconnect from the service
            proxy.Close();
        }
    }
}
